# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.msp.postgresql.v1alpha1.config``"""

import builtins as builtins
import collections.abc as abc
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import nebius.api.nebius.msp.postgresql.v1alpha1.config.postgresql_pb2 as postgresql_pb2
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.unset as unset
import typing as typing
#@ local imports here @#

# file: nebius/msp/postgresql/v1alpha1/config/postgresql.proto
class PostgresqlConfig16(pb_classes.Message):
    __PB2_CLASS__ = postgresql_pb2.PostgresqlConfig16
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.postgresql.v1alpha1.config.PostgresqlConfig16",postgresql_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class __OneOfClass__autovacuum_work_mem__(pb_classes.OneOf):
        name: builtins.str= "_autovacuum_work_mem"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__autovacuum_work_mem_autovacuum_work_mem__(__OneOfClass__autovacuum_work_mem__):
        field: typing.Literal["autovacuum_work_mem"] = "autovacuum_work_mem"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.autovacuum_work_mem
    
    @builtins.property
    def _autovacuum_work_mem(self) -> __OneOfClass__autovacuum_work_mem_autovacuum_work_mem__|None:
        field_name_1: str|None = super().which_field_in_oneof("_autovacuum_work_mem")
        match field_name_1:
            case "autovacuum_work_mem":
                return self.__OneOfClass__autovacuum_work_mem_autovacuum_work_mem__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__statement_timeout__(pb_classes.OneOf):
        name: builtins.str= "_statement_timeout"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__statement_timeout_statement_timeout__(__OneOfClass__statement_timeout__):
        field: typing.Literal["statement_timeout"] = "statement_timeout"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.statement_timeout
    
    @builtins.property
    def _statement_timeout(self) -> __OneOfClass__statement_timeout_statement_timeout__|None:
        field_name_1: str|None = super().which_field_in_oneof("_statement_timeout")
        match field_name_1:
            case "statement_timeout":
                return self.__OneOfClass__statement_timeout_statement_timeout__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__idle_in_transaction_session_timeout__(pb_classes.OneOf):
        name: builtins.str= "_idle_in_transaction_session_timeout"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__idle_in_transaction_session_timeout_idle_in_transaction_session_timeout__(__OneOfClass__idle_in_transaction_session_timeout__):
        field: typing.Literal["idle_in_transaction_session_timeout"] = "idle_in_transaction_session_timeout"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.idle_in_transaction_session_timeout
    
    @builtins.property
    def _idle_in_transaction_session_timeout(self) -> __OneOfClass__idle_in_transaction_session_timeout_idle_in_transaction_session_timeout__|None:
        field_name_1: str|None = super().which_field_in_oneof("_idle_in_transaction_session_timeout")
        match field_name_1:
            case "idle_in_transaction_session_timeout":
                return self.__OneOfClass__idle_in_transaction_session_timeout_idle_in_transaction_session_timeout__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__autovacuum_vacuum_cost_delay__(pb_classes.OneOf):
        name: builtins.str= "_autovacuum_vacuum_cost_delay"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__autovacuum_vacuum_cost_delay_autovacuum_vacuum_cost_delay__(__OneOfClass__autovacuum_vacuum_cost_delay__):
        field: typing.Literal["autovacuum_vacuum_cost_delay"] = "autovacuum_vacuum_cost_delay"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.autovacuum_vacuum_cost_delay
    
    @builtins.property
    def _autovacuum_vacuum_cost_delay(self) -> __OneOfClass__autovacuum_vacuum_cost_delay_autovacuum_vacuum_cost_delay__|None:
        field_name_1: str|None = super().which_field_in_oneof("_autovacuum_vacuum_cost_delay")
        match field_name_1:
            case "autovacuum_vacuum_cost_delay":
                return self.__OneOfClass__autovacuum_vacuum_cost_delay_autovacuum_vacuum_cost_delay__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__autovacuum_vacuum_cost_limit__(pb_classes.OneOf):
        name: builtins.str= "_autovacuum_vacuum_cost_limit"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__autovacuum_vacuum_cost_limit_autovacuum_vacuum_cost_limit__(__OneOfClass__autovacuum_vacuum_cost_limit__):
        field: typing.Literal["autovacuum_vacuum_cost_limit"] = "autovacuum_vacuum_cost_limit"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.autovacuum_vacuum_cost_limit
    
    @builtins.property
    def _autovacuum_vacuum_cost_limit(self) -> __OneOfClass__autovacuum_vacuum_cost_limit_autovacuum_vacuum_cost_limit__|None:
        field_name_1: str|None = super().which_field_in_oneof("_autovacuum_vacuum_cost_limit")
        match field_name_1:
            case "autovacuum_vacuum_cost_limit":
                return self.__OneOfClass__autovacuum_vacuum_cost_limit_autovacuum_vacuum_cost_limit__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__autovacuum_naptime__(pb_classes.OneOf):
        name: builtins.str= "_autovacuum_naptime"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__autovacuum_naptime_autovacuum_naptime__(__OneOfClass__autovacuum_naptime__):
        field: typing.Literal["autovacuum_naptime"] = "autovacuum_naptime"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.autovacuum_naptime
    
    @builtins.property
    def _autovacuum_naptime(self) -> __OneOfClass__autovacuum_naptime_autovacuum_naptime__|None:
        field_name_1: str|None = super().which_field_in_oneof("_autovacuum_naptime")
        match field_name_1:
            case "autovacuum_naptime":
                return self.__OneOfClass__autovacuum_naptime_autovacuum_naptime__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__autovacuum_vacuum_scale_factor__(pb_classes.OneOf):
        name: builtins.str= "_autovacuum_vacuum_scale_factor"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__autovacuum_vacuum_scale_factor_autovacuum_vacuum_scale_factor__(__OneOfClass__autovacuum_vacuum_scale_factor__):
        field: typing.Literal["autovacuum_vacuum_scale_factor"] = "autovacuum_vacuum_scale_factor"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.float":
            return self._message.autovacuum_vacuum_scale_factor
    
    @builtins.property
    def _autovacuum_vacuum_scale_factor(self) -> __OneOfClass__autovacuum_vacuum_scale_factor_autovacuum_vacuum_scale_factor__|None:
        field_name_1: str|None = super().which_field_in_oneof("_autovacuum_vacuum_scale_factor")
        match field_name_1:
            case "autovacuum_vacuum_scale_factor":
                return self.__OneOfClass__autovacuum_vacuum_scale_factor_autovacuum_vacuum_scale_factor__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__autovacuum_analyze_scale_factor__(pb_classes.OneOf):
        name: builtins.str= "_autovacuum_analyze_scale_factor"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__autovacuum_analyze_scale_factor_autovacuum_analyze_scale_factor__(__OneOfClass__autovacuum_analyze_scale_factor__):
        field: typing.Literal["autovacuum_analyze_scale_factor"] = "autovacuum_analyze_scale_factor"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.float":
            return self._message.autovacuum_analyze_scale_factor
    
    @builtins.property
    def _autovacuum_analyze_scale_factor(self) -> __OneOfClass__autovacuum_analyze_scale_factor_autovacuum_analyze_scale_factor__|None:
        field_name_1: str|None = super().which_field_in_oneof("_autovacuum_analyze_scale_factor")
        match field_name_1:
            case "autovacuum_analyze_scale_factor":
                return self.__OneOfClass__autovacuum_analyze_scale_factor_autovacuum_analyze_scale_factor__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__default_transaction_read_only__(pb_classes.OneOf):
        name: builtins.str= "_default_transaction_read_only"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__default_transaction_read_only_default_transaction_read_only__(__OneOfClass__default_transaction_read_only__):
        field: typing.Literal["default_transaction_read_only"] = "default_transaction_read_only"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.bool":
            return self._message.default_transaction_read_only
    
    @builtins.property
    def _default_transaction_read_only(self) -> __OneOfClass__default_transaction_read_only_default_transaction_read_only__|None:
        field_name_1: str|None = super().which_field_in_oneof("_default_transaction_read_only")
        match field_name_1:
            case "default_transaction_read_only":
                return self.__OneOfClass__default_transaction_read_only_default_transaction_read_only__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__search_path__(pb_classes.OneOf):
        name: builtins.str= "_search_path"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__search_path_search_path__(__OneOfClass__search_path__):
        field: typing.Literal["search_path"] = "search_path"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.str":
            return self._message.search_path
    
    @builtins.property
    def _search_path(self) -> __OneOfClass__search_path_search_path__|None:
        field_name_1: str|None = super().which_field_in_oneof("_search_path")
        match field_name_1:
            case "search_path":
                return self.__OneOfClass__search_path_search_path__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__max_connections__(pb_classes.OneOf):
        name: builtins.str= "_max_connections"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__max_connections_max_connections__(__OneOfClass__max_connections__):
        field: typing.Literal["max_connections"] = "max_connections"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.max_connections
    
    @builtins.property
    def _max_connections(self) -> __OneOfClass__max_connections_max_connections__|None:
        field_name_1: str|None = super().which_field_in_oneof("_max_connections")
        match field_name_1:
            case "max_connections":
                return self.__OneOfClass__max_connections_max_connections__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    class __OneOfClass__shared_buffers__(pb_classes.OneOf):
        name: builtins.str= "_shared_buffers"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__()
            self._message: "PostgresqlConfig16" = msg
    
    class __OneOfClass__shared_buffers_shared_buffers__(__OneOfClass__shared_buffers__):
        field: typing.Literal["shared_buffers"] = "shared_buffers"
        
        def __init__(self, msg: "PostgresqlConfig16") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.shared_buffers
    
    @builtins.property
    def _shared_buffers(self) -> __OneOfClass__shared_buffers_shared_buffers__|None:
        field_name_1: str|None = super().which_field_in_oneof("_shared_buffers")
        match field_name_1:
            case "shared_buffers":
                return self.__OneOfClass__shared_buffers_shared_buffers__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        autovacuum_work_mem: "builtins.int|None|unset.UnsetType" = unset.Unset,
        statement_timeout: "builtins.int|None|unset.UnsetType" = unset.Unset,
        idle_in_transaction_session_timeout: "builtins.int|None|unset.UnsetType" = unset.Unset,
        autovacuum_vacuum_cost_delay: "builtins.int|None|unset.UnsetType" = unset.Unset,
        autovacuum_vacuum_cost_limit: "builtins.int|None|unset.UnsetType" = unset.Unset,
        autovacuum_naptime: "builtins.int|None|unset.UnsetType" = unset.Unset,
        autovacuum_vacuum_scale_factor: "builtins.float|None|unset.UnsetType" = unset.Unset,
        autovacuum_analyze_scale_factor: "builtins.float|None|unset.UnsetType" = unset.Unset,
        default_transaction_read_only: "builtins.bool|None|unset.UnsetType" = unset.Unset,
        search_path: "builtins.str|None|unset.UnsetType" = unset.Unset,
        max_connections: "builtins.int|None|unset.UnsetType" = unset.Unset,
        shared_buffers: "builtins.int|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(autovacuum_work_mem, unset.UnsetType):
            self.autovacuum_work_mem = autovacuum_work_mem
        if not isinstance(statement_timeout, unset.UnsetType):
            self.statement_timeout = statement_timeout
        if not isinstance(idle_in_transaction_session_timeout, unset.UnsetType):
            self.idle_in_transaction_session_timeout = idle_in_transaction_session_timeout
        if not isinstance(autovacuum_vacuum_cost_delay, unset.UnsetType):
            self.autovacuum_vacuum_cost_delay = autovacuum_vacuum_cost_delay
        if not isinstance(autovacuum_vacuum_cost_limit, unset.UnsetType):
            self.autovacuum_vacuum_cost_limit = autovacuum_vacuum_cost_limit
        if not isinstance(autovacuum_naptime, unset.UnsetType):
            self.autovacuum_naptime = autovacuum_naptime
        if not isinstance(autovacuum_vacuum_scale_factor, unset.UnsetType):
            self.autovacuum_vacuum_scale_factor = autovacuum_vacuum_scale_factor
        if not isinstance(autovacuum_analyze_scale_factor, unset.UnsetType):
            self.autovacuum_analyze_scale_factor = autovacuum_analyze_scale_factor
        if not isinstance(default_transaction_read_only, unset.UnsetType):
            self.default_transaction_read_only = default_transaction_read_only
        if not isinstance(search_path, unset.UnsetType):
            self.search_path = search_path
        if not isinstance(max_connections, unset.UnsetType):
            self.max_connections = max_connections
        if not isinstance(shared_buffers, unset.UnsetType):
            self.shared_buffers = shared_buffers
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "autovacuum_work_mem",
            "statement_timeout",
            "idle_in_transaction_session_timeout",
            "autovacuum_vacuum_cost_delay",
            "autovacuum_vacuum_cost_limit",
            "autovacuum_naptime",
            "autovacuum_vacuum_scale_factor",
            "autovacuum_analyze_scale_factor",
            "default_transaction_read_only",
            "search_path",
            "max_connections",
            "shared_buffers",
            "_autovacuum_work_mem",
            "_statement_timeout",
            "_idle_in_transaction_session_timeout",
            "_autovacuum_vacuum_cost_delay",
            "_autovacuum_vacuum_cost_limit",
            "_autovacuum_naptime",
            "_autovacuum_vacuum_scale_factor",
            "_autovacuum_analyze_scale_factor",
            "_default_transaction_read_only",
            "_search_path",
            "_max_connections",
            "_shared_buffers",
        ]
    
    @builtins.property
    def autovacuum_work_mem(self) -> "builtins.int|None":
        """
        in kilobytes.
        """
        
        return super()._get_field("autovacuum_work_mem", explicit_presence=True,
        )
    @autovacuum_work_mem.setter
    def autovacuum_work_mem(self, value: "builtins.int|None") -> None:
        return super()._set_field("autovacuum_work_mem",value,explicit_presence=True,
        )
    
    @builtins.property
    def statement_timeout(self) -> "builtins.int|None":
        """
        in milliseconds.
        """
        
        return super()._get_field("statement_timeout", explicit_presence=True,
        )
    @statement_timeout.setter
    def statement_timeout(self, value: "builtins.int|None") -> None:
        return super()._set_field("statement_timeout",value,explicit_presence=True,
        )
    
    @builtins.property
    def idle_in_transaction_session_timeout(self) -> "builtins.int|None":
        """
        in milliseconds.
        """
        
        return super()._get_field("idle_in_transaction_session_timeout", explicit_presence=True,
        )
    @idle_in_transaction_session_timeout.setter
    def idle_in_transaction_session_timeout(self, value: "builtins.int|None") -> None:
        return super()._set_field("idle_in_transaction_session_timeout",value,explicit_presence=True,
        )
    
    @builtins.property
    def autovacuum_vacuum_cost_delay(self) -> "builtins.int|None":
        """
        in milliseconds.
        """
        
        return super()._get_field("autovacuum_vacuum_cost_delay", explicit_presence=True,
        )
    @autovacuum_vacuum_cost_delay.setter
    def autovacuum_vacuum_cost_delay(self, value: "builtins.int|None") -> None:
        return super()._set_field("autovacuum_vacuum_cost_delay",value,explicit_presence=True,
        )
    
    @builtins.property
    def autovacuum_vacuum_cost_limit(self) -> "builtins.int|None":
        return super()._get_field("autovacuum_vacuum_cost_limit", explicit_presence=True,
        )
    @autovacuum_vacuum_cost_limit.setter
    def autovacuum_vacuum_cost_limit(self, value: "builtins.int|None") -> None:
        return super()._set_field("autovacuum_vacuum_cost_limit",value,explicit_presence=True,
        )
    
    @builtins.property
    def autovacuum_naptime(self) -> "builtins.int|None":
        """
        in seconds.
        """
        
        return super()._get_field("autovacuum_naptime", explicit_presence=True,
        )
    @autovacuum_naptime.setter
    def autovacuum_naptime(self, value: "builtins.int|None") -> None:
        return super()._set_field("autovacuum_naptime",value,explicit_presence=True,
        )
    
    @builtins.property
    def autovacuum_vacuum_scale_factor(self) -> "builtins.float|None":
        return super()._get_field("autovacuum_vacuum_scale_factor", explicit_presence=True,
        )
    @autovacuum_vacuum_scale_factor.setter
    def autovacuum_vacuum_scale_factor(self, value: "builtins.float|None") -> None:
        return super()._set_field("autovacuum_vacuum_scale_factor",value,explicit_presence=True,
        )
    
    @builtins.property
    def autovacuum_analyze_scale_factor(self) -> "builtins.float|None":
        return super()._get_field("autovacuum_analyze_scale_factor", explicit_presence=True,
        )
    @autovacuum_analyze_scale_factor.setter
    def autovacuum_analyze_scale_factor(self, value: "builtins.float|None") -> None:
        return super()._set_field("autovacuum_analyze_scale_factor",value,explicit_presence=True,
        )
    
    @builtins.property
    def default_transaction_read_only(self) -> "builtins.bool|None":
        return super()._get_field("default_transaction_read_only", explicit_presence=True,
        )
    @default_transaction_read_only.setter
    def default_transaction_read_only(self, value: "builtins.bool|None") -> None:
        return super()._set_field("default_transaction_read_only",value,explicit_presence=True,
        )
    
    @builtins.property
    def search_path(self) -> "builtins.str|None":
        return super()._get_field("search_path", explicit_presence=True,
        )
    @search_path.setter
    def search_path(self, value: "builtins.str|None") -> None:
        return super()._set_field("search_path",value,explicit_presence=True,
        )
    
    @builtins.property
    def max_connections(self) -> "builtins.int|None":
        return super()._get_field("max_connections", explicit_presence=True,
        )
    @max_connections.setter
    def max_connections(self, value: "builtins.int|None") -> None:
        return super()._set_field("max_connections",value,explicit_presence=True,
        )
    
    @builtins.property
    def shared_buffers(self) -> "builtins.int|None":
        """
        in kilobytes.
        """
        
        return super()._get_field("shared_buffers", explicit_presence=True,
        )
    @shared_buffers.setter
    def shared_buffers(self, value: "builtins.int|None") -> None:
        return super()._set_field("shared_buffers",value,explicit_presence=True,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "autovacuum_work_mem":"autovacuum_work_mem",
        "statement_timeout":"statement_timeout",
        "idle_in_transaction_session_timeout":"idle_in_transaction_session_timeout",
        "autovacuum_vacuum_cost_delay":"autovacuum_vacuum_cost_delay",
        "autovacuum_vacuum_cost_limit":"autovacuum_vacuum_cost_limit",
        "autovacuum_naptime":"autovacuum_naptime",
        "autovacuum_vacuum_scale_factor":"autovacuum_vacuum_scale_factor",
        "autovacuum_analyze_scale_factor":"autovacuum_analyze_scale_factor",
        "default_transaction_read_only":"default_transaction_read_only",
        "search_path":"search_path",
        "max_connections":"max_connections",
        "shared_buffers":"shared_buffers",
        "_autovacuum_work_mem":"_autovacuum_work_mem",
        "_statement_timeout":"_statement_timeout",
        "_idle_in_transaction_session_timeout":"_idle_in_transaction_session_timeout",
        "_autovacuum_vacuum_cost_delay":"_autovacuum_vacuum_cost_delay",
        "_autovacuum_vacuum_cost_limit":"_autovacuum_vacuum_cost_limit",
        "_autovacuum_naptime":"_autovacuum_naptime",
        "_autovacuum_vacuum_scale_factor":"_autovacuum_vacuum_scale_factor",
        "_autovacuum_analyze_scale_factor":"_autovacuum_analyze_scale_factor",
        "_default_transaction_read_only":"_default_transaction_read_only",
        "_search_path":"_search_path",
        "_max_connections":"_max_connections",
        "_shared_buffers":"_shared_buffers",
    }
    
__all__ = [
    #@ local import names here @#
    "PostgresqlConfig16",
]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import access_key_pb2 as nebius_dot_iam_dot_v1_dot_access__key__pb2
from nebius.api.nebius.iam.v1 import access_key_service_pb2 as nebius_dot_iam_dot_v1_dot_access__key__service__pb2


class AccessKeyServiceStub(object):
    """Access keys API v1 is depricated. It's known to malfunction under certain conditions.
    Use Access keys API v2 instead. Access keys create by API v1 are available using Access keys API v2.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/Create',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.CreateAccessKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/List',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysResponse.FromString,
                )
        self.ListByAccount = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/ListByAccount',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysByAccountRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/Update',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.UpdateAccessKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.GetById = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/GetById',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeyByIdRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_access__key__pb2.AccessKey.FromString,
                )
        self.GetByAwsId = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/GetByAwsId',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeyByAwsIdRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_access__key__pb2.AccessKey.FromString,
                )
        self.GetSecretOnce = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/GetSecretOnce',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeySecretOnceRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeySecretOnceResponse.FromString,
                )
        self.Activate = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/Activate',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ActivateAccessKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Deactivate = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/Deactivate',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.DeactivateAccessKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.iam.v1.AccessKeyService/Delete',
                request_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.DeleteAccessKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class AccessKeyServiceServicer(object):
    """Access keys API v1 is depricated. It's known to malfunction under certain conditions.
    Use Access keys API v2 instead. Access keys create by API v1 are available using Access keys API v2.
    """

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListByAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByAwsId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecretOnce(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deactivate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccessKeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.CreateAccessKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysResponse.SerializeToString,
            ),
            'ListByAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.ListByAccount,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysByAccountRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.UpdateAccessKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetById,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeyByIdRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_access__key__pb2.AccessKey.SerializeToString,
            ),
            'GetByAwsId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByAwsId,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeyByAwsIdRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_access__key__pb2.AccessKey.SerializeToString,
            ),
            'GetSecretOnce': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecretOnce,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeySecretOnceRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeySecretOnceResponse.SerializeToString,
            ),
            'Activate': grpc.unary_unary_rpc_method_handler(
                    servicer.Activate,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ActivateAccessKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deactivate,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.DeactivateAccessKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_access__key__service__pb2.DeleteAccessKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.iam.v1.AccessKeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccessKeyService(object):
    """Access keys API v1 is depricated. It's known to malfunction under certain conditions.
    Use Access keys API v2 instead. Access keys create by API v1 are available using Access keys API v2.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/Create',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.CreateAccessKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/List',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListByAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/ListByAccount',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysByAccountRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ListAccessKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/Update',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.UpdateAccessKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/GetById',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeyByIdRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_access__key__pb2.AccessKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByAwsId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/GetByAwsId',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeyByAwsIdRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_access__key__pb2.AccessKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSecretOnce(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/GetSecretOnce',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeySecretOnceRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.GetAccessKeySecretOnceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/Activate',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.ActivateAccessKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/Deactivate',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.DeactivateAccessKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AccessKeyService/Delete',
            nebius_dot_iam_dot_v1_dot_access__key__service__pb2.DeleteAccessKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/node_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/compute/v1/node_service.proto\x12\x11nebius.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\"\xf1\x02\n\x17NodeSetUnhealthyRequest\x12\'\n\x0binstance_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\ninstanceId\x12n\n\x11health_check_info\x18\x02 \x01(\x0b\x32:.nebius.compute.v1.NodeSetUnhealthyRequest.HealthCheckInfoB\x06\xbaH\x03\xc8\x01\x01R\x0fhealthCheckInfo\x12\x17\n\x07\x64ry_run\x18\x03 \x01(\x08R\x06\x64ryRun\x1a\xa3\x01\n\x0fHealthCheckInfo\x12\x43\n\x0bobserved_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\nobservedAt\x12!\n\x08\x63heck_id\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07\x63heckId\x12(\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0b\x64\x65scription\"\x1a\n\x18NodeSetUnhealthyResponse2\x82\x01\n\x0bNodeService\x12g\n\x0cSetUnhealthy\x12*.nebius.compute.v1.NodeSetUnhealthyRequest\x1a+.nebius.compute.v1.NodeSetUnhealthyResponse\x1a\n\xbaJ\x07\x63omputeB_\n\x18\x61i.nebius.pub.compute.v1B\x10NodeServiceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.node_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\020NodeServiceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _NODESETUNHEALTHYREQUEST_HEALTHCHECKINFO.fields_by_name['observed_at']._options = None
  _NODESETUNHEALTHYREQUEST_HEALTHCHECKINFO.fields_by_name['observed_at']._serialized_options = b'\272H\003\310\001\001'
  _NODESETUNHEALTHYREQUEST_HEALTHCHECKINFO.fields_by_name['check_id']._options = None
  _NODESETUNHEALTHYREQUEST_HEALTHCHECKINFO.fields_by_name['check_id']._serialized_options = b'\272H\003\310\001\001'
  _NODESETUNHEALTHYREQUEST_HEALTHCHECKINFO.fields_by_name['description']._options = None
  _NODESETUNHEALTHYREQUEST_HEALTHCHECKINFO.fields_by_name['description']._serialized_options = b'\272H\003\310\001\001'
  _NODESETUNHEALTHYREQUEST.fields_by_name['instance_id']._options = None
  _NODESETUNHEALTHYREQUEST.fields_by_name['instance_id']._serialized_options = b'\272H\003\310\001\001'
  _NODESETUNHEALTHYREQUEST.fields_by_name['health_check_info']._options = None
  _NODESETUNHEALTHYREQUEST.fields_by_name['health_check_info']._serialized_options = b'\272H\003\310\001\001'
  _NODESERVICE._options = None
  _NODESERVICE._serialized_options = b'\272J\007compute'
  _globals['_NODESETUNHEALTHYREQUEST']._serialized_start=148
  _globals['_NODESETUNHEALTHYREQUEST']._serialized_end=517
  _globals['_NODESETUNHEALTHYREQUEST_HEALTHCHECKINFO']._serialized_start=354
  _globals['_NODESETUNHEALTHYREQUEST_HEALTHCHECKINFO']._serialized_end=517
  _globals['_NODESETUNHEALTHYRESPONSE']._serialized_start=519
  _globals['_NODESETUNHEALTHYRESPONSE']._serialized_end=545
  _globals['_NODESERVICE']._serialized_start=548
  _globals['_NODESERVICE']._serialized_end=678
# @@protoc_insertion_point(module_scope)



import re

from nebius.base.error import SDKError


def fix_name(method_name: str) -> str:
    if method_name[0] != "/":
        return method_name
    method_name = method_name[1:]
    return method_name.replace("/", ".")


class InvalidMethodNameError(SDKError):
    pass


pattern = r"([\./]?)([\w_]+(?:\.[\w_]+)*)(?:(\1|[\./]))([\w_]+)"


def service_from_method_name(input_string: str) -> str:
    match = re.match(pattern, input_string)
    if not match:
        raise InvalidMethodNameError(f"The method name {input_string} is malformed.")

    group1 = match.group(1)  # Delimiter (optional)
    group2 = match.group(2)  # First part of the name
    group3 = match.group(3)  # Delimiter or fallback
    group4 = match.group(4)  # Second part of the name

    # Validate group2 and group4
    if not group2:
        raise InvalidMethodNameError("Method name has to include service name.")
    if not group4:
        raise InvalidMethodNameError("Method name has to include method.")

    # Validate group3 consistency with group1 if group1 is found
    if group1 and group3 != group1:
        raise InvalidMethodNameError(
            f"Delimiter {group3} does not match the initial delimiter {group1}."
        )
    return group2



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/access_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import access_key_pb2 as nebius_dot_iam_dot_v1_dot_access__key__pb2
from nebius.api.nebius.iam.v1 import access_pb2 as nebius_dot_iam_dot_v1_dot_access__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/iam/v1/access_key_service.proto\x12\rnebius.iam.v1\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1enebius/iam/v1/access_key.proto\x1a\x1anebius/iam/v1/access.proto\"\x8a\x01\n\x16\x43reateAccessKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v1.AccessKeySpecR\x04spec\"X\n\x0bKeyIdentity\x12\x10\n\x02id\x18\x01 \x01(\tH\x00R\x02id\x12+\n\x11\x61ws_access_key_id\x18\x02 \x01(\tH\x00R\x0e\x61wsAccessKeyIdB\n\n\x08identity\"/\n\x1dGetAccessKeySecretOnceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\")\n\x17GetAccessKeyByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"G\n\x1aGetAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"\x9b\x01\n\x15ListAccessKeysRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"\xa6\x01\n\x1eListAccessKeysByAccountRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x16.nebius.iam.v1.AccountR\x07\x61\x63\x63ount\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x8a\x01\n\x16UpdateAccessKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v1.AccessKeySpecR\x04spec\"F\n\x18\x41\x63tivateAccessKeyRequest\x12*\n\x02id\x18\x01 \x01(\x0b\x32\x1a.nebius.iam.v1.KeyIdentityR\x02id\"H\n\x1a\x44\x65\x61\x63tivateAccessKeyRequest\x12*\n\x02id\x18\x01 \x01(\x0b\x32\x1a.nebius.iam.v1.KeyIdentityR\x02id\"D\n\x16\x44\x65leteAccessKeyRequest\x12*\n\x02id\x18\x01 \x01(\x0b\x32\x1a.nebius.iam.v1.KeyIdentityR\x02id\"=\n\x1eGetAccessKeySecretOnceResponse\x12\x1b\n\x06secret\x18\x01 \x01(\tB\x03\xc0J\x01R\x06secret\"p\n\x16ListAccessKeysResponse\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x18.nebius.iam.v1.AccessKeyR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xfc\x07\n\x10\x41\x63\x63\x65ssKeyService\x12L\n\x06\x43reate\x12%.nebius.iam.v1.CreateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12S\n\x04List\x12$.nebius.iam.v1.ListAccessKeysRequest\x1a%.nebius.iam.v1.ListAccessKeysResponse\x12\x65\n\rListByAccount\x12-.nebius.iam.v1.ListAccessKeysByAccountRequest\x1a%.nebius.iam.v1.ListAccessKeysResponse\x12L\n\x06Update\x12%.nebius.iam.v1.UpdateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12K\n\x07GetById\x12&.nebius.iam.v1.GetAccessKeyByIdRequest\x1a\x18.nebius.iam.v1.AccessKey\x12Q\n\nGetByAwsId\x12).nebius.iam.v1.GetAccessKeyByAwsIdRequest\x1a\x18.nebius.iam.v1.AccessKey\x12l\n\rGetSecretOnce\x12,.nebius.iam.v1.GetAccessKeySecretOnceRequest\x1a-.nebius.iam.v1.GetAccessKeySecretOnceResponse\x12P\n\x08\x41\x63tivate\x12\'.nebius.iam.v1.ActivateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12T\n\nDeactivate\x12).nebius.iam.v1.DeactivateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12L\n\x06\x44\x65lete\x12%.nebius.iam.v1.DeleteAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x8b\x01\x88\x02\x01\xbaJ\x07\x63pl.iam\xd2J{\n\n2026-09-01\x12mAccess keys API v1 is deprecated, use the v2 version instead. Keys produced by API v1 are available using v2.B\\\n\x14\x61i.nebius.pub.iam.v1B\x15\x41\x63\x63\x65ssKeyServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.access_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\025AccessKeyServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GETACCESSKEYSECRETONCERESPONSE.fields_by_name['secret']._options = None
  _GETACCESSKEYSECRETONCERESPONSE.fields_by_name['secret']._serialized_options = b'\300J\001'
  _ACCESSKEYSERVICE._options = None
  _ACCESSKEYSERVICE._serialized_options = b'\210\002\001\272J\007cpl.iam\322J{\n\n2026-09-01\022mAccess keys API v1 is deprecated, use the v2 version instead. Keys produced by API v1 are available using v2.'
  _globals['_CREATEACCESSKEYREQUEST']._serialized_start=211
  _globals['_CREATEACCESSKEYREQUEST']._serialized_end=349
  _globals['_KEYIDENTITY']._serialized_start=351
  _globals['_KEYIDENTITY']._serialized_end=439
  _globals['_GETACCESSKEYSECRETONCEREQUEST']._serialized_start=441
  _globals['_GETACCESSKEYSECRETONCEREQUEST']._serialized_end=488
  _globals['_GETACCESSKEYBYIDREQUEST']._serialized_start=490
  _globals['_GETACCESSKEYBYIDREQUEST']._serialized_end=531
  _globals['_GETACCESSKEYBYAWSIDREQUEST']._serialized_start=533
  _globals['_GETACCESSKEYBYAWSIDREQUEST']._serialized_end=604
  _globals['_LISTACCESSKEYSREQUEST']._serialized_start=607
  _globals['_LISTACCESSKEYSREQUEST']._serialized_end=762
  _globals['_LISTACCESSKEYSBYACCOUNTREQUEST']._serialized_start=765
  _globals['_LISTACCESSKEYSBYACCOUNTREQUEST']._serialized_end=931
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_start=934
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_end=1072
  _globals['_ACTIVATEACCESSKEYREQUEST']._serialized_start=1074
  _globals['_ACTIVATEACCESSKEYREQUEST']._serialized_end=1144
  _globals['_DEACTIVATEACCESSKEYREQUEST']._serialized_start=1146
  _globals['_DEACTIVATEACCESSKEYREQUEST']._serialized_end=1218
  _globals['_DELETEACCESSKEYREQUEST']._serialized_start=1220
  _globals['_DELETEACCESSKEYREQUEST']._serialized_end=1288
  _globals['_GETACCESSKEYSECRETONCERESPONSE']._serialized_start=1290
  _globals['_GETACCESSKEYSECRETONCERESPONSE']._serialized_end=1351
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_start=1353
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_end=1465
  _globals['_ACCESSKEYSERVICE']._serialized_start=1468
  _globals['_ACCESSKEYSERVICE']._serialized_end=2488
# @@protoc_insertion_point(module_scope)



from collections.abc import Iterable

from google.protobuf.any_pb2 import Any as AnyPb
from google.rpc.status_pb2 import Status as StatusPb  # type: ignore
from grpc import RpcError, Status, StatusCode
from grpc_status import rpc_status

from nebius.api.nebius.common.v1.error_pb2 import ServiceError as ServiceErrorPb


def pb2_from_status(
    status: StatusPb,  # type: ignore[unused-ignore]
    remove_from_details: bool = False,
) -> list[ServiceErrorPb]:
    ret = list[ServiceErrorPb]()
    rest = list[AnyPb]()
    for detail in status.details:  # type: ignore[unused-ignore]
        if detail.Is(ServiceErrorPb.DESCRIPTOR):  # type: ignore[unused-ignore]
            se = ServiceErrorPb()
            detail.Unpack(se)  # type: ignore[unused-ignore]
            ret.append(se)
        elif remove_from_details:
            rest.append(detail)  # type: ignore[unused-ignore]
    if remove_from_details:
        status.ClearField("details")  # type: ignore[unused-ignore]
        status.details.extend(rest)  # type: ignore[unused-ignore]
    return ret


def pb2_from_error(err: RpcError) -> list[ServiceErrorPb]:
    status = rpc_status.from_call(err)  # type: ignore[unused-ignore,arg-type]
    if status is None:
        return list[ServiceErrorPb]()
    return pb2_from_status(status)


def to_anypb(err: ServiceErrorPb) -> AnyPb:
    ret = AnyPb()
    ret.Pack(err)  # type: ignore[unused-ignore]
    return ret


def pbrpc_status_of_errors(  # type: ignore[unused-ignore]
    code: int,
    message: str,
    errors: ServiceErrorPb | Iterable[ServiceErrorPb],
) -> StatusPb:
    if isinstance(errors, ServiceErrorPb):
        errors = [errors]
    pbs = [to_anypb(err) for err in errors]
    ret = StatusPb()  # type: ignore[unused-ignore]
    if isinstance(code, StatusCode):
        ret.code = code[0]  # type: ignore
    elif isinstance(code, tuple) and isinstance(code[0], int):
        ret.code = code[0]
    else:
        ret.code = code
    ret.message = message
    ret.details.extend(pbs)  # type: ignore[unused-ignore]
    return ret  # type: ignore[unused-ignore]


def grpc_status_of_errors(
    code: int,
    message: str,
    errors: ServiceErrorPb | Iterable[ServiceErrorPb],
) -> Status:
    return rpc_status.to_status(pbrpc_status_of_errors(code, message, errors))


Metadata = tuple[
    tuple[str, str | bytes],
    ...,
]


def trailing_metadata_of_errors(
    errors: ServiceErrorPb | Iterable[ServiceErrorPb],
    status_code: int = 1,
    status_message: str = "",
) -> Metadata:
    return grpc_status_of_errors(status_code, status_message, errors).trailing_metadata



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import static_key_pb2 as nebius_dot_iam_dot_v1_dot_static__key__pb2
from nebius.api.nebius.iam.v1 import static_key_service_pb2 as nebius_dot_iam_dot_v1_dot_static__key__service__pb2


class StaticKeyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Issue = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Issue',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/List',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Get',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/GetByName',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Delete',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.DeleteStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Find = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Find',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyResponse.FromString,
                )
        self.Revoke = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Revoke',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.RevokeStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class StaticKeyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Issue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Find(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Revoke(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StaticKeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Issue': grpc.unary_unary_rpc_method_handler(
                    servicer.Issue,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyByNameRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.DeleteStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Find': grpc.unary_unary_rpc_method_handler(
                    servicer.Find,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyResponse.SerializeToString,
            ),
            'Revoke': grpc.unary_unary_rpc_method_handler(
                    servicer.Revoke,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.RevokeStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.iam.v1.StaticKeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StaticKeyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Issue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Issue',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/List',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Get',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/GetByName',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyByNameRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Delete',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.DeleteStaticKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Find(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Find',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Revoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Revoke',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.RevokeStaticKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``buf.validate``"""

#@ local imports here @#

# file: buf/validate/validate.proto
# file skipped
__all__ = [
    #@ local import names here @#
    "Ignore",
    "KnownRegex",
    "message",
    "oneof",
    "field",
    "predefined",
    "Constraint",
    "MessageConstraints",
    "OneofConstraints",
    "FieldConstraints",
    "PredefinedConstraints",
    "FloatRules",
    "DoubleRules",
    "Int32Rules",
    "Int64Rules",
    "UInt32Rules",
    "UInt64Rules",
    "SInt32Rules",
    "SInt64Rules",
    "Fixed32Rules",
    "Fixed64Rules",
    "SFixed32Rules",
    "SFixed64Rules",
    "BoolRules",
    "StringRules",
    "BytesRules",
    "EnumRules",
    "RepeatedRules",
    "MapRules",
    "AnyRules",
    "DurationRules",
    "TimestampRules",
    "Violations",
    "Violation",
    "FieldPath",
    "FieldPathElement",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/subnet_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.vpc.v1 import subnet_pb2 as nebius_dot_vpc_dot_v1_dot_subnet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nebius/vpc/v1/subnet_service.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1anebius/vpc/v1/subnet.proto\"*\n\x10GetSubnetRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"Y\n\x16GetSubnetByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"u\n\x12ListSubnetsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x80\x01\n\x1bListSubnetsByNetworkRequest\x12%\n\nnetwork_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tnetworkId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"j\n\x13ListSubnetsResponse\x12+\n\x05items\x18\x01 \x03(\x0b\x32\x15.nebius.vpc.v1.SubnetR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xd9\x02\n\x13\x43reateSubnetRequest\x12\x8a\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc9\x01\xbaH\xc5\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\xc8\x01\x01R\x08metadata\x12\x35\n\x04spec\x18\x02 \x01(\x0b\x32\x19.nebius.vpc.v1.SubnetSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xce\x02\n\x13UpdateSubnetRequest\x12\x87\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc6\x01\xbaH\xc2\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')R\x08metadata\x12-\n\x04spec\x18\x02 \x01(\x0b\x32\x19.nebius.vpc.v1.SubnetSpecR\x04spec\"%\n\x13\x44\x65leteSubnetRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id2\xb2\x04\n\rSubnetService\x12=\n\x03Get\x12\x1f.nebius.vpc.v1.GetSubnetRequest\x1a\x15.nebius.vpc.v1.Subnet\x12I\n\tGetByName\x12%.nebius.vpc.v1.GetSubnetByNameRequest\x1a\x15.nebius.vpc.v1.Subnet\x12M\n\x04List\x12!.nebius.vpc.v1.ListSubnetsRequest\x1a\".nebius.vpc.v1.ListSubnetsResponse\x12_\n\rListByNetwork\x12*.nebius.vpc.v1.ListSubnetsByNetworkRequest\x1a\".nebius.vpc.v1.ListSubnetsResponse\x12I\n\x06\x43reate\x12\".nebius.vpc.v1.CreateSubnetRequest\x1a\x1b.nebius.common.v1.Operation\x12I\n\x06Update\x12\".nebius.vpc.v1.UpdateSubnetRequest\x1a\x1b.nebius.common.v1.Operation\x12I\n\x06\x44\x65lete\x12\".nebius.vpc.v1.DeleteSubnetRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x06\xbaJ\x03vpcBY\n\x14\x61i.nebius.pub.vpc.v1B\x12SubnetServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.subnet_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\022SubnetServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _GETSUBNETREQUEST.fields_by_name['id']._options = None
  _GETSUBNETREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETSUBNETBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETSUBNETBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETSUBNETBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETSUBNETBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTSUBNETSREQUEST.fields_by_name['parent_id']._options = None
  _LISTSUBNETSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTSUBNETSBYNETWORKREQUEST.fields_by_name['network_id']._options = None
  _LISTSUBNETSBYNETWORKREQUEST.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001'
  _CREATESUBNETREQUEST.fields_by_name['metadata']._options = None
  _CREATESUBNETREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\305\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\310\001\001'
  _CREATESUBNETREQUEST.fields_by_name['spec']._options = None
  _CREATESUBNETREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _UPDATESUBNETREQUEST.fields_by_name['metadata']._options = None
  _UPDATESUBNETREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\302\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')'
  _SUBNETSERVICE._options = None
  _SUBNETSERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETSUBNETREQUEST']._serialized_start=203
  _globals['_GETSUBNETREQUEST']._serialized_end=245
  _globals['_GETSUBNETBYNAMEREQUEST']._serialized_start=247
  _globals['_GETSUBNETBYNAMEREQUEST']._serialized_end=336
  _globals['_LISTSUBNETSREQUEST']._serialized_start=338
  _globals['_LISTSUBNETSREQUEST']._serialized_end=455
  _globals['_LISTSUBNETSBYNETWORKREQUEST']._serialized_start=458
  _globals['_LISTSUBNETSBYNETWORKREQUEST']._serialized_end=586
  _globals['_LISTSUBNETSRESPONSE']._serialized_start=588
  _globals['_LISTSUBNETSRESPONSE']._serialized_end=694
  _globals['_CREATESUBNETREQUEST']._serialized_start=697
  _globals['_CREATESUBNETREQUEST']._serialized_end=1042
  _globals['_UPDATESUBNETREQUEST']._serialized_start=1045
  _globals['_UPDATESUBNETREQUEST']._serialized_end=1379
  _globals['_DELETESUBNETREQUEST']._serialized_start=1381
  _globals['_DELETESUBNETREQUEST']._serialized_end=1418
  _globals['_SUBNETSERVICE']._serialized_start=1421
  _globals['_SUBNETSERVICE']._serialized_end=1983
# @@protoc_insertion_point(module_scope)



import json
from dataclasses import dataclass
from logging import getLogger
from pathlib import Path
from typing import Any

from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey

from .pk_file import WrongKeyTypeError
from .service_account import Reader as BaseReader
from .service_account import ServiceAccount

log = getLogger(__name__)


@dataclass
class SubjectCredentials:
    type: str
    alg: str
    private_key: str
    kid: str
    iss: str
    sub: str

    def validate(self) -> None:
        if self.type != "" and self.type != "JWT":
            raise ValueError(
                f"Invalid service account credentials type: '{self.type}',"
                " only 'JWT' is supported."
            )

        if self.alg != "RS256":
            raise ValueError(
                f"Invalid service account algorithm: '{self.alg}',"
                " only 'RS256' is supported."
            )

        if self.iss != self.sub:
            raise ValueError(
                "Issuer must be the same as subject: " f"'{self.iss}' != '{self.sub}'."
            )

    def parse_private_key(self) -> RSAPrivateKey:
        pk = serialization.load_pem_private_key(
            self.private_key.encode("utf-8"), password=None, backend=default_backend()
        )

        if not isinstance(pk, RSAPrivateKey):
            raise WrongKeyTypeError(pk)
        return pk


@dataclass
class ServiceAccountCredentials:
    subject_credentials: SubjectCredentials

    @staticmethod
    def from_json(data: dict[str, Any]) -> "ServiceAccountCredentials":
        subject_data = data["subject-credentials"]
        subject_credentials = SubjectCredentials(
            type=subject_data["type"] if "type" in subject_data else "",
            alg=subject_data["alg"],
            private_key=subject_data["private-key"],
            kid=subject_data["kid"],
            iss=subject_data["iss"],
            sub=subject_data["sub"],
        )
        subject_credentials.validate()
        return ServiceAccountCredentials(subject_credentials)


class Reader(BaseReader):
    def __init__(
        self,
        filename: str | Path,
    ) -> None:
        filename = Path(filename).expanduser()

        log.debug(f"reading SA from Credentials file: {filename}")
        with open(filename, "rb") as f:
            data = json.load(f)
        self._credentials = ServiceAccountCredentials.from_json(data)
        self._parsed_key = self._credentials.subject_credentials.parse_private_key()

    def read(self) -> ServiceAccount:
        return ServiceAccount(
            self._parsed_key,
            self._credentials.subject_credentials.kid,
            self._credentials.subject_credentials.sub,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/service_account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#nebius/iam/v1/service_account.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xda\x01\n\x0eServiceAccount\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12=\n\x04spec\x18\x02 \x01(\x0b\x32!.nebius.iam.v1.ServiceAccountSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x41\n\x06status\x18\x03 \x01(\x0b\x32#.nebius.iam.v1.ServiceAccountStatusB\x04\xbaJ\x01\x05R\x06status\"6\n\x12ServiceAccountSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\".\n\x14ServiceAccountStatus\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\"P\n\x18ServiceAccountAttributes\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scriptionBZ\n\x14\x61i.nebius.pub.iam.v1B\x13ServiceAccountProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.service_account_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\023ServiceAccountProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _SERVICEACCOUNT.fields_by_name['metadata']._options = None
  _SERVICEACCOUNT.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _SERVICEACCOUNT.fields_by_name['spec']._options = None
  _SERVICEACCOUNT.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _SERVICEACCOUNT.fields_by_name['status']._options = None
  _SERVICEACCOUNT.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _globals['_SERVICEACCOUNT']._serialized_start=143
  _globals['_SERVICEACCOUNT']._serialized_end=361
  _globals['_SERVICEACCOUNTSPEC']._serialized_start=363
  _globals['_SERVICEACCOUNTSPEC']._serialized_end=417
  _globals['_SERVICEACCOUNTSTATUS']._serialized_start=419
  _globals['_SERVICEACCOUNTSTATUS']._serialized_end=465
  _globals['_SERVICEACCOUNTATTRIBUTES']._serialized_start=467
  _globals['_SERVICEACCOUNTATTRIBUTES']._serialized_end=547
# @@protoc_insertion_point(module_scope)



"""File-backed static token bearer.

This module provides a tiny bearer implementation that reads a raw
access token from a filesystem path. It is useful for local testing,
scripting or environments where a short-lived token is written to a
file by an external process or host system.

The behaviour is intentionally simple: every fetch reads the token
file contents and returns a :class:`Token`. Empty file contents raise
an :class:`nebius.base.error.SDKError`.

Examples
--------

Create a bearer that reads from ``~/.nebius/token``::

    from nebius.aio.token.file import Bearer
    bearer = Bearer("~/.nebius/token")
    token = await bearer.receiver().fetch()

Use in code that expects a :class:`nebius.aio.token.token.Bearer`::

    sdk = SDK(credentials=bearer)

"""

from logging import getLogger
from pathlib import Path

from nebius.base.error import SDKError

from .token import Bearer as ParentBearer
from .token import Receiver as ParentReceiver
from .token import Token

log = getLogger(__name__)


class Receiver(ParentReceiver):
    """A receiver that reads a token from a filesystem path.

    Each call to :meth:`_fetch` opens and reads the configured file, so
    the token may change between fetches if the file is updated by an
    external process.

    :param file: :class:`pathlib.Path` pointing to a file containing a
        raw access token (UTF-8 text). The file is read on each fetch
        and must contain a non-empty token string.
    """

    def __init__(self, file: Path) -> None:
        """Create a file-backed receiver."""
        super().__init__()
        self._file = file

    async def _fetch(
        self, timeout: float | None = None, options: dict[str, str] | None = None
    ) -> Token:
        """Read the token file and return a :class:`Token`.

        :param timeout: Ignored for file-backed receivers but accepted for
            API compatibility.
        :param options: Ignored; present for API compatibility.
        :returns: A :class:`Token` constructed from the file contents.
        :raises SDKError: If the file contains an empty string.
        :raises OSError: If the file cannot be opened.
        """
        with open(self._file, "r") as f:
            token_value = f.read().strip()
        if token_value == "":
            raise SDKError("empty token file provided")
        tok = Token(token_value)
        log.debug(f"fetched token {tok} from file {self._file}")
        return tok

    def can_retry(
        self,
        err: Exception,
        options: dict[str, str] | None = None,
    ) -> bool:
        """Indicate that file-backed tokens are not retryable.

        The token is static from the perspective of this receiver; retries
        are not useful because there is no remote call to repeat.
        """
        return False


class Bearer(ParentBearer):
    """Bearer that provides file-backed :class:`Receiver` instances.

    The bearer accepts either a string path or a :class:`pathlib.Path`
    and expands the user's home directory. It does not validate the
    existence of the file at construction time.

    :param file: Filesystem path (string or :class:`pathlib.Path`) to
        the token file. Tilde expansion is performed.

    Example
    -------

    Construct a bearer and use it to initialize the SDK::

        from nebius.sdk import SDK
        from nebius.aio.token.file import Bearer

        sdk = SDK(credentials=Bearer("~/nebius.token"))
    """

    def __init__(self, file: str | Path) -> None:
        """Create a bearer for the given token file."""
        super().__init__()
        self._file = Path(file).expanduser()

    def receiver(self) -> Receiver:
        """Return a :class:`Receiver` that reads tokens from the file.

        :returns: A new :class:`Receiver` bound to the configured file.
        """
        return Receiver(self._file)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Authorization(_message.Message):
    __slots__ = ["authorized"]
    AUTHORIZED_FIELD_NUMBER: _ClassVar[int]
    authorized: bool
    def __init__(self, authorized: bool = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    STATE_UNSPECIFIED: _ClassVar[State]
    ACTIVE: _ClassVar[State]
    SCHEDULING_FOR_DELETION: _ClassVar[State]
    SCHEDULED_FOR_DELETION: _ClassVar[State]
    SCHEDULING_FOR_DELETION_BY_PARENT: _ClassVar[State]
    SCHEDULED_FOR_DELETION_BY_PARENT: _ClassVar[State]
    UNDELETING: _ClassVar[State]
    PURGING: _ClassVar[State]
    PURGED: _ClassVar[State]
    CREATING: _ClassVar[State]
STATE_UNSPECIFIED: State
ACTIVE: State
SCHEDULING_FOR_DELETION: State
SCHEDULED_FOR_DELETION: State
SCHEDULING_FOR_DELETION_BY_PARENT: State
SCHEDULED_FOR_DELETION_BY_PARENT: State
UNDELETING: State
PURGING: State
PURGED: State
CREATING: State



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.vpc.v1alpha1 import pool_pb2 as _pool_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Subnet(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: SubnetSpec
    status: SubnetStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[SubnetSpec, _Mapping]] = ..., status: _Optional[_Union[SubnetStatus, _Mapping]] = ...) -> None: ...

class SubnetSpec(_message.Message):
    __slots__ = ["network_id", "pools", "enable_egress_nat"]
    NETWORK_ID_FIELD_NUMBER: _ClassVar[int]
    POOLS_FIELD_NUMBER: _ClassVar[int]
    ENABLE_EGRESS_NAT_FIELD_NUMBER: _ClassVar[int]
    network_id: str
    pools: _containers.RepeatedCompositeFieldContainer[SubnetPool]
    enable_egress_nat: bool
    def __init__(self, network_id: _Optional[str] = ..., pools: _Optional[_Iterable[_Union[SubnetPool, _Mapping]]] = ..., enable_egress_nat: bool = ...) -> None: ...

class SubnetPool(_message.Message):
    __slots__ = ["spec", "pool_id"]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    POOL_ID_FIELD_NUMBER: _ClassVar[int]
    spec: SubnetPoolSpec
    pool_id: str
    def __init__(self, spec: _Optional[_Union[SubnetPoolSpec, _Mapping]] = ..., pool_id: _Optional[str] = ...) -> None: ...

class SubnetPoolSpec(_message.Message):
    __slots__ = ["version", "cidrs"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CIDRS_FIELD_NUMBER: _ClassVar[int]
    version: _pool_pb2.IpVersion
    cidrs: _containers.RepeatedCompositeFieldContainer[SubnetCidr]
    def __init__(self, version: _Optional[_Union[_pool_pb2.IpVersion, str]] = ..., cidrs: _Optional[_Iterable[_Union[SubnetCidr, _Mapping]]] = ...) -> None: ...

class SubnetCidr(_message.Message):
    __slots__ = ["cidr", "state", "allowed_mask"]
    CIDR_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_MASK_FIELD_NUMBER: _ClassVar[int]
    cidr: str
    state: _pool_pb2.PoolCidrState
    allowed_mask: int
    def __init__(self, cidr: _Optional[str] = ..., state: _Optional[_Union[_pool_pb2.PoolCidrState, str]] = ..., allowed_mask: _Optional[int] = ...) -> None: ...

class SubnetStatus(_message.Message):
    __slots__ = ["state", "ipv4_cidrs"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[SubnetStatus.State]
        CREATING: _ClassVar[SubnetStatus.State]
        READY: _ClassVar[SubnetStatus.State]
        DELETING: _ClassVar[SubnetStatus.State]
    STATE_UNSPECIFIED: SubnetStatus.State
    CREATING: SubnetStatus.State
    READY: SubnetStatus.State
    DELETING: SubnetStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    IPV4_CIDRS_FIELD_NUMBER: _ClassVar[int]
    state: SubnetStatus.State
    ipv4_cidrs: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, state: _Optional[_Union[SubnetStatus.State, str]] = ..., ipv4_cidrs: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/group_membership_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import group_membership_pb2 as nebius_dot_iam_dot_v1_dot_group__membership__pb2
from nebius.api.nebius.iam.v1 import group_pb2 as nebius_dot_iam_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,nebius/iam/v1/group_membership_service.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a$nebius/iam/v1/group_membership.proto\x1a\x19nebius/iam/v1/group.proto\"\xcc\x01\n\x1c\x43reateGroupMembershipRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32\".nebius.iam.v1.GroupMembershipSpecR\x04spec\x12,\n\x12revoke_after_hours\x18\x04 \x01(\x03R\x10revokeAfterHours\"6\n\x1c\x44\x65leteGroupMembershipRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"3\n\x19GetGroupMembershipRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xa9\x01\n\x1bListGroupMembershipsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"\xa3\x01\n\x13ListMemberOfRequest\x12%\n\nsubject_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tsubjectId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"\x88\x01\n\x1cListGroupMembershipsResponse\x12@\n\x0bmemberships\x18\x01 \x03(\x0b\x32\x1e.nebius.iam.v1.GroupMembershipR\x0bmemberships\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xa4\x01\n*ListGroupMembershipsWithAttributesResponse\x12N\n\x0bmemberships\x18\x01 \x03(\x0b\x32,.nebius.iam.v1.GroupMembershipWithAttributesR\x0bmemberships\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"j\n\x14ListMemberOfResponse\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x14.nebius.iam.v1.GroupR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xd0\x05\n\x16GroupMembershipService\x12R\n\x06\x43reate\x12+.nebius.iam.v1.CreateGroupMembershipRequest\x1a\x1b.nebius.common.v1.Operation\x12O\n\x03Get\x12(.nebius.iam.v1.GetGroupMembershipRequest\x1a\x1e.nebius.iam.v1.GroupMembership\x12k\n\x11GetWithAttributes\x12(.nebius.iam.v1.GetGroupMembershipRequest\x1a,.nebius.iam.v1.GroupMembershipWithAttributes\x12R\n\x06\x44\x65lete\x12+.nebius.iam.v1.DeleteGroupMembershipRequest\x1a\x1b.nebius.common.v1.Operation\x12\x66\n\x0bListMembers\x12*.nebius.iam.v1.ListGroupMembershipsRequest\x1a+.nebius.iam.v1.ListGroupMembershipsResponse\x12\x82\x01\n\x19ListMembersWithAttributes\x12*.nebius.iam.v1.ListGroupMembershipsRequest\x1a\x39.nebius.iam.v1.ListGroupMembershipsWithAttributesResponse\x12W\n\x0cListMemberOf\x12\".nebius.iam.v1.ListMemberOfRequest\x1a#.nebius.iam.v1.ListMemberOfResponse\x1a\n\xbaJ\x07\x63pl.iamBb\n\x14\x61i.nebius.pub.iam.v1B\x1bGroupMembershipServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.group_membership_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\033GroupMembershipServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _CREATEGROUPMEMBERSHIPREQUEST.fields_by_name['metadata']._options = None
  _CREATEGROUPMEMBERSHIPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _DELETEGROUPMEMBERSHIPREQUEST.fields_by_name['id']._options = None
  _DELETEGROUPMEMBERSHIPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETGROUPMEMBERSHIPREQUEST.fields_by_name['id']._options = None
  _GETGROUPMEMBERSHIPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTGROUPMEMBERSHIPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTGROUPMEMBERSHIPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTMEMBEROFREQUEST.fields_by_name['subject_id']._options = None
  _LISTMEMBEROFREQUEST.fields_by_name['subject_id']._serialized_options = b'\272H\003\310\001\001'
  _GROUPMEMBERSHIPSERVICE._options = None
  _GROUPMEMBERSHIPSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEGROUPMEMBERSHIPREQUEST']._serialized_start=251
  _globals['_CREATEGROUPMEMBERSHIPREQUEST']._serialized_end=455
  _globals['_DELETEGROUPMEMBERSHIPREQUEST']._serialized_start=457
  _globals['_DELETEGROUPMEMBERSHIPREQUEST']._serialized_end=511
  _globals['_GETGROUPMEMBERSHIPREQUEST']._serialized_start=513
  _globals['_GETGROUPMEMBERSHIPREQUEST']._serialized_end=564
  _globals['_LISTGROUPMEMBERSHIPSREQUEST']._serialized_start=567
  _globals['_LISTGROUPMEMBERSHIPSREQUEST']._serialized_end=736
  _globals['_LISTMEMBEROFREQUEST']._serialized_start=739
  _globals['_LISTMEMBEROFREQUEST']._serialized_end=902
  _globals['_LISTGROUPMEMBERSHIPSRESPONSE']._serialized_start=905
  _globals['_LISTGROUPMEMBERSHIPSRESPONSE']._serialized_end=1041
  _globals['_LISTGROUPMEMBERSHIPSWITHATTRIBUTESRESPONSE']._serialized_start=1044
  _globals['_LISTGROUPMEMBERSHIPSWITHATTRIBUTESRESPONSE']._serialized_end=1208
  _globals['_LISTMEMBEROFRESPONSE']._serialized_start=1210
  _globals['_LISTMEMBEROFRESPONSE']._serialized_end=1316
  _globals['_GROUPMEMBERSHIPSERVICE']._serialized_start=1319
  _globals['_GROUPMEMBERSHIPSERVICE']._serialized_end=2039
# @@protoc_insertion_point(module_scope)



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.rpc import status_pb2 as _status_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ResourceEvent(_message.Message):
    __slots__ = ["occurred_at", "level", "code", "message", "error"]
    class Level(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNSPECIFIED: _ClassVar[ResourceEvent.Level]
        DEBUG: _ClassVar[ResourceEvent.Level]
        INFO: _ClassVar[ResourceEvent.Level]
        WARN: _ClassVar[ResourceEvent.Level]
        ERROR: _ClassVar[ResourceEvent.Level]
    UNSPECIFIED: ResourceEvent.Level
    DEBUG: ResourceEvent.Level
    INFO: ResourceEvent.Level
    WARN: ResourceEvent.Level
    ERROR: ResourceEvent.Level
    OCCURRED_AT_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    occurred_at: _timestamp_pb2.Timestamp
    level: ResourceEvent.Level
    code: str
    message: str
    error: _status_pb2.Status
    def __init__(self, occurred_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., level: _Optional[_Union[ResourceEvent.Level, str]] = ..., code: _Optional[str] = ..., message: _Optional[str] = ..., error: _Optional[_Union[_status_pb2.Status, _Mapping]] = ...) -> None: ...

class RecurrentResourceEvent(_message.Message):
    __slots__ = ["first_occurred_at", "last_occurrence", "occurrence_count"]
    FIRST_OCCURRED_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_OCCURRENCE_FIELD_NUMBER: _ClassVar[int]
    OCCURRENCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    first_occurred_at: _timestamp_pb2.Timestamp
    last_occurrence: ResourceEvent
    occurrence_count: int
    def __init__(self, first_occurred_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_occurrence: _Optional[_Union[ResourceEvent, _Mapping]] = ..., occurrence_count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/applications/v1alpha1/k8s_release.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.nebius/applications/v1alpha1/k8s_release.proto\x12\x1cnebius.applications.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xf2\x01\n\nK8sRelease\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.applications.v1alpha1.K8sReleaseSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12L\n\x06status\x18\x03 \x01(\x0b\x32..nebius.applications.v1alpha1.K8sReleaseStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\"\xf6\x02\n\x0eK8sReleaseSpec\x12)\n\ncluster_id\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tclusterId\x12-\n\x0cproduct_slug\x18\x02 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x0bproductSlug\x12(\n\tnamespace\x18\x03 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tnamespace\x12\x35\n\x10\x61pplication_name\x18\x04 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x0f\x61pplicationName\x12\x1f\n\x06values\x18\x05 \x01(\tB\x07\xbaJ\x01\x04\xc0J\x01R\x06values\x12P\n\x03set\x18\x06 \x03(\x0b\x32\x35.nebius.applications.v1alpha1.K8sReleaseSpec.SetEntryB\x07\xbaJ\x01\x04\xc0J\x01R\x03set\x1a\x36\n\x08SetEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe1\x01\n\x10K8sReleaseStatus\x12J\n\x05state\x18\x01 \x01(\x0e\x32\x34.nebius.applications.v1alpha1.K8sReleaseStatus.StateR\x05state\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"\\\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08\x44\x45PLOYED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0e\n\nINSTALLING\x10\x05\x42t\n#ai.nebius.pub.applications.v1alpha1B\x0fK8SReleaseProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/applications/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.applications.v1alpha1.k8s_release_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.applications.v1alpha1B\017K8SReleaseProtoP\001Z:github.com/nebius/gosdk/proto/nebius/applications/v1alpha1'
  _K8SRELEASE.fields_by_name['metadata']._options = None
  _K8SRELEASE.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _K8SRELEASE.fields_by_name['spec']._options = None
  _K8SRELEASE.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _K8SRELEASE.fields_by_name['status']._options = None
  _K8SRELEASE.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _K8SRELEASE._options = None
  _K8SRELEASE._serialized_options = b'\272J\001\002'
  _K8SRELEASESPEC_SETENTRY._options = None
  _K8SRELEASESPEC_SETENTRY._serialized_options = b'8\001'
  _K8SRELEASESPEC.fields_by_name['cluster_id']._options = None
  _K8SRELEASESPEC.fields_by_name['cluster_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _K8SRELEASESPEC.fields_by_name['product_slug']._options = None
  _K8SRELEASESPEC.fields_by_name['product_slug']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _K8SRELEASESPEC.fields_by_name['namespace']._options = None
  _K8SRELEASESPEC.fields_by_name['namespace']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _K8SRELEASESPEC.fields_by_name['application_name']._options = None
  _K8SRELEASESPEC.fields_by_name['application_name']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _K8SRELEASESPEC.fields_by_name['values']._options = None
  _K8SRELEASESPEC.fields_by_name['values']._serialized_options = b'\272J\001\004\300J\001'
  _K8SRELEASESPEC.fields_by_name['set']._options = None
  _K8SRELEASESPEC.fields_by_name['set']._serialized_options = b'\272J\001\004\300J\001'
  _globals['_K8SRELEASE']._serialized_start=169
  _globals['_K8SRELEASE']._serialized_end=411
  _globals['_K8SRELEASESPEC']._serialized_start=414
  _globals['_K8SRELEASESPEC']._serialized_end=788
  _globals['_K8SRELEASESPEC_SETENTRY']._serialized_start=734
  _globals['_K8SRELEASESPEC_SETENTRY']._serialized_end=788
  _globals['_K8SRELEASESTATUS']._serialized_start=791
  _globals['_K8SRELEASESTATUS']._serialized_end=1016
  _globals['_K8SRELEASESTATUS_STATE']._serialized_start=924
  _globals['_K8SRELEASESTATUS_STATE']._serialized_end=1016
# @@protoc_insertion_point(module_scope)



from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AccessPermit(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: AccessPermitSpec
    status: AccessPermitStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[AccessPermitSpec, _Mapping]] = ..., status: _Optional[_Union[AccessPermitStatus, _Mapping]] = ...) -> None: ...

class AccessPermitSpec(_message.Message):
    __slots__ = ["resource_id", "role"]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    role: str
    def __init__(self, resource_id: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class AccessPermitStatus(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mk8s/v1/node_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.mk8s.v1 import node_group_pb2 as nebius_dot_mk8s_dot_v1_dot_node__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'nebius/mk8s/v1/node_group_service.proto\x12\x0enebius.mk8s.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1fnebius/mk8s/v1/node_group.proto\"\x8a\x01\n&GetNodeGroupCompatibilityMatrixRequest\x12\x44\n\x1a\x63luster_kubernetes_version\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x18\x63lusterKubernetesVersion\x12\x1a\n\x08platform\x18\x02 \x01(\tR\x08platform\"i\n\x1cNodeGroupCompatibilityMatrix\x12I\n\x08versions\x18\x01 \x03(\x0b\x32-.nebius.mk8s.v1.NodeGroupCompatibilityVersionR\x08versions\"\x97\x01\n\x1dNodeGroupCompatibilityVersion\x12-\n\x12kubernetes_version\x18\x01 \x01(\tR\x11kubernetesVersion\x12G\n\x05items\x18\x02 \x03(\x0b\x32\x31.nebius.mk8s.v1.NodeGroupCompatibilityVersionItemR\x05items\"\x8d\x01\n!NodeGroupCompatibilityVersionItem\x12\x0e\n\x02os\x18\x01 \x01(\tR\x02os\x12%\n\x0e\x64rivers_preset\x18\x03 \x01(\tR\rdriversPreset\x12\x31\n\x14\x63ompatible_platforms\x18\x05 \x03(\tR\x13\x63ompatiblePlatforms\"\x9b\x01\n\x16\x43reateNodeGroupRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.mk8s.v1.NodeGroupSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"X\n\x13GetNodeGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\"x\n\x15ListNodeGroupsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"q\n\x16ListNodeGroupsResponse\x12/\n\x05items\x18\x01 \x03(\x0b\x32\x19.nebius.mk8s.v1.NodeGroupR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x93\x01\n\x16UpdateNodeGroupRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.mk8s.v1.NodeGroupSpecR\x04spec\"0\n\x16\x44\x65leteNodeGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x9a\x01\n\x17UpgradeNodeGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12P\n\x14latest_infra_version\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyB\x04\xbaJ\x01\x06H\x00R\x12latestInfraVersionB\x15\n\x0cupgrade_type\x12\x05\xbaH\x02\x08\x01\x32\xc3\x05\n\x10NodeGroupService\x12\x45\n\x03Get\x12#.nebius.mk8s.v1.GetNodeGroupRequest\x1a\x19.nebius.mk8s.v1.NodeGroup\x12J\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\x19.nebius.mk8s.v1.NodeGroup\x12U\n\x04List\x12%.nebius.mk8s.v1.ListNodeGroupsRequest\x1a&.nebius.mk8s.v1.ListNodeGroupsResponse\x12M\n\x06\x43reate\x12&.nebius.mk8s.v1.CreateNodeGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06Update\x12&.nebius.mk8s.v1.UpdateNodeGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06\x44\x65lete\x12&.nebius.mk8s.v1.DeleteNodeGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12O\n\x07Upgrade\x12\'.nebius.mk8s.v1.UpgradeNodeGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12~\n\x16GetCompatibilityMatrix\x12\x36.nebius.mk8s.v1.GetNodeGroupCompatibilityMatrixRequest\x1a,.nebius.mk8s.v1.NodeGroupCompatibilityMatrix\x1a\x07\xbaJ\x04mk8sB^\n\x15\x61i.nebius.pub.mk8s.v1B\x15NodeGroupServiceProtoP\x01Z,github.com/nebius/gosdk/proto/nebius/mk8s/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mk8s.v1.node_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025ai.nebius.pub.mk8s.v1B\025NodeGroupServiceProtoP\001Z,github.com/nebius/gosdk/proto/nebius/mk8s/v1'
  _GETNODEGROUPCOMPATIBILITYMATRIXREQUEST.fields_by_name['cluster_kubernetes_version']._options = None
  _GETNODEGROUPCOMPATIBILITYMATRIXREQUEST.fields_by_name['cluster_kubernetes_version']._serialized_options = b'\272H\003\310\001\001'
  _CREATENODEGROUPREQUEST.fields_by_name['metadata']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATENODEGROUPREQUEST.fields_by_name['spec']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _GETNODEGROUPREQUEST.fields_by_name['id']._options = None
  _GETNODEGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTNODEGROUPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATENODEGROUPREQUEST.fields_by_name['metadata']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _DELETENODEGROUPREQUEST.fields_by_name['id']._options = None
  _DELETENODEGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPGRADENODEGROUPREQUEST.oneofs_by_name['upgrade_type']._options = None
  _UPGRADENODEGROUPREQUEST.oneofs_by_name['upgrade_type']._serialized_options = b'\272H\002\010\001'
  _UPGRADENODEGROUPREQUEST.fields_by_name['id']._options = None
  _UPGRADENODEGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPGRADENODEGROUPREQUEST.fields_by_name['latest_infra_version']._options = None
  _UPGRADENODEGROUPREQUEST.fields_by_name['latest_infra_version']._serialized_options = b'\272J\001\006'
  _NODEGROUPSERVICE._options = None
  _NODEGROUPSERVICE._serialized_options = b'\272J\004mk8s'
  _globals['_GETNODEGROUPCOMPATIBILITYMATRIXREQUEST']._serialized_start=244
  _globals['_GETNODEGROUPCOMPATIBILITYMATRIXREQUEST']._serialized_end=382
  _globals['_NODEGROUPCOMPATIBILITYMATRIX']._serialized_start=384
  _globals['_NODEGROUPCOMPATIBILITYMATRIX']._serialized_end=489
  _globals['_NODEGROUPCOMPATIBILITYVERSION']._serialized_start=492
  _globals['_NODEGROUPCOMPATIBILITYVERSION']._serialized_end=643
  _globals['_NODEGROUPCOMPATIBILITYVERSIONITEM']._serialized_start=646
  _globals['_NODEGROUPCOMPATIBILITYVERSIONITEM']._serialized_end=787
  _globals['_CREATENODEGROUPREQUEST']._serialized_start=790
  _globals['_CREATENODEGROUPREQUEST']._serialized_end=945
  _globals['_GETNODEGROUPREQUEST']._serialized_start=947
  _globals['_GETNODEGROUPREQUEST']._serialized_end=1035
  _globals['_LISTNODEGROUPSREQUEST']._serialized_start=1037
  _globals['_LISTNODEGROUPSREQUEST']._serialized_end=1157
  _globals['_LISTNODEGROUPSRESPONSE']._serialized_start=1159
  _globals['_LISTNODEGROUPSRESPONSE']._serialized_end=1272
  _globals['_UPDATENODEGROUPREQUEST']._serialized_start=1275
  _globals['_UPDATENODEGROUPREQUEST']._serialized_end=1422
  _globals['_DELETENODEGROUPREQUEST']._serialized_start=1424
  _globals['_DELETENODEGROUPREQUEST']._serialized_end=1472
  _globals['_UPGRADENODEGROUPREQUEST']._serialized_start=1475
  _globals['_UPGRADENODEGROUPREQUEST']._serialized_end=1629
  _globals['_NODEGROUPSERVICE']._serialized_start=1632
  _globals['_NODEGROUPSERVICE']._serialized_end=2339
# @@protoc_insertion_point(module_scope)
